@@ -85,7 +85,7 @@ include("templates/footer.ihtml");
  * FUNCTIONS
  *****************************************************************************/
 
-function print_add_iva_form($id) {
+function print_add_iva_form() {
 /* print a blank iva form so we can add a new iva percentual */
 
 	global $CFG, $ME;
@@ -128,6 +128,10 @@ function delete_iva($id) {
 
 	$qid = db_begin();
 
+	/* select the iva percentual to be deleted */
+	$qid = db_query("SELECT iva from iva WHERE id = '$id'");
+	$frm = db_fetch_array ($qid, 0);
+
 	/* delete this iva percentual */
 	$qid = db_query("DELETE FROM iva WHERE id = '$id'");
 
@@ -230,9 +234,6 @@ function import_iva($userfile) {
 //		$fldarr = split("\",\"",ereg_replace("^\"|\"..$|\".$","",$line));
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
 
-		$arr = db_fetch_array($qid,0);
-		$pid = $arr[0];
-
 		/* Stripping dangerous characters from fields */
 		$fldarr[0] = ereg_replace("\'","",$fldarr[0]);
 
