@@ -301,6 +301,7 @@ function insert_user($frm) {
 
 	global $CFG, $SESSION;
 	global $myday, $mymonth;
+	include ($CFG->global);
 
 	$date = $myday[date("w")] . date(" j") . "-" . date("n") . "-" . date("Y H:i:s");
 	$fromip = getenv("REMOTE_ADDR");
@@ -344,8 +345,9 @@ function insert_user($frm) {
 function update_user($frm) {
 /* update the user record in the database */
 
-	global $SESSION;
+	global $CFG, $SESSION;
 	global $username;
+	include ($CFG->global);
 
 	$qid = db_query("
 	UPDATE users SET
@@ -435,6 +437,8 @@ function import_users($userfile) {
 	$fcontents = file ($userfile);
 	/* Traverse the file */
 	while (list ($line_num, $line) = each ($fcontents)) {
+		// Microsoft Stupidity Suppression
+		$line = ereg_replace(chr(13), "", $line);
 //		$fldarr = split("\",\"",ereg_replace("^\"|\"..$|\".$","",$line));
 		$fldarr = split("\t",ereg_replace("\n$","",$line));
 //echo "<b>" . $line_num . "</b>:" . $line . "<br>";
