@@ -78,8 +78,9 @@ if (! isset($SESSION)) {
 
 // Loaded modules
 $SESSION["brand_used"] = 1;
-$SESSION["iva_used"] = 0;
-$SESSION["iva_value"] = 0;	// not significant if IVA is used
+$SESSION["iva_used"] = 1;
+//$SESSION["iva_value"] = 0;	// not significant if IVA is used
+$IVA = "VAT";
 
 $SESSION["price_must_be_integer"] = 0;
 	// 1 --> the price must be integer (Italian Lit, for example)
