@@ -107,7 +107,7 @@ function build_category_navigator(&$output, $parent=1, $indent="..") {
         $numr = db_num_rows($qid);
         for ($i=0;$i<$numr;$i++) {
                 $cat =  db_fetch_object($qid, $i);
-		$output .= $indent . "<div class=normal>" . $cat->name . "</div>" . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "^main" . "\n";
+		$output .= $indent . "<div class=normal>" . stripslashes($cat->name) . "</div>" . "^" . $CFG->wwwroot . "/shopping/?" . getenv("QUERY_STRING") . "&id=" . $cat->id . "^main" . "\n";
                 if ($cat->id != $parent) {
                         build_category_navigator($output, $cat->id, $indent.".");
                 }
@@ -207,7 +207,7 @@ function get_category_tree($id=1) {
 	$qid = db_query("SELECT parent_id, name FROM categories WHERE id = '$id' ORDER BY on_special, name");
 	if (db_num_rows($qid)) {
 		list($parent, $name) = db_fetch_row($qid, 0);
-		$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>$name</a>";
+		$name = "<a href='$CFG->wwwroot/shopping/?id=$id'>" . stripslashes($name) . "</a>";
 	} else {
 		$parent = 1;
 		$name = "";
