@@ -54,7 +54,7 @@ function pvwbr(&$var) {
 	$appoggio = isset($var) ? htmlSpecialChars(stripslashes($var)) : "";
 	$appoggio = ereg_replace ("\n", "<br>", $appoggio);
 */
-	$appoggio = nl2br($var);
+	$appoggio = nl2br(stripslashes($var));
 	echo $appoggio == "" ? "&nbsp;" : $appoggio;
 }
 
