@@ -36,7 +36,8 @@ $The_category = "La categoria";
 $Brand = "Marca";
 $Brands = "Marche";
 $The_brand = "La marca";
-$The_IVA_Percentual = "La percentuale di IVA";
+global $IVA;	// taken from application.inc.php where the scope is a problem
+$The_IVA_Percentual = "La percentuale di " . $IVA;
 $Product = "Prodotto";
 $Products = "Prodotti";
 $The_product = "Il prodotto";
@@ -46,7 +47,7 @@ $Edit_Product = "Modifica prodotto";
 $Items = "pezzi";
 $Add_Subcategory = "Aggiungi sottocategoria";
 $Add_Brand = "Aggiungi marca";
-$Add_IVA = "Aggiungi IVA";
+$Add_IVA = "Aggiungi " . $IVA;
 $back = "indietro";
 $BACK = "INDIETRO";
 $Address = "Via/Piazza";
@@ -117,8 +118,8 @@ $Categories_Management = "Amministrazione delle categorie";
 $C_Import_Categories = "Importa categorie";
 $Brands_Management = "Amministrazione delle marche";
 $C_Import_Brands = "Importa marche";
-$C_Import_IVA = "Importa percentuali IVA";
-$IVA_Management = "Amministrazione dei valori di IVA";
+$C_Import_IVA = "Importa percentuali " . $IVA;
+$IVA_Management = "Amministrazione dei valori di " . $IVA;
 $Orders_Log_ca = "Diario degli ordini - Contrassegno";
 $Orders_Log_cc = "Diario degli ordini - Carta di Credito";
 $Products_Management = "Amministrazione dei prodotti";
@@ -143,7 +144,7 @@ $Discount = "Sconto";
 $Starting_from = "a partire da";
 $C_Add_Category = "[+C] Aggiungi categoria";
 $C_Add_Brand = "[+M] Aggiungi marca";
-$C_Add_IVA = "[+I] Aggiungi percentuale IVA";
+$C_Add_IVA = "[+I] Aggiungi percentuale " . $IVA;
 $C_Add_Product = "[+P] Aggiungi prodotto";
 $Action = "Azione";
 $User = "Utente";
@@ -163,10 +164,10 @@ $Add_a_subcategory_under = "Aggiungi una sottocategoria di";
 $Add_a_product_under = "Aggiungi un prodotto a";
 $Edit_this_category = "Modifica questa categoria";
 $Edit_this_brand = "Modifica questa marca";
-$Edit_this_IVA = "Modifica questa percentuale di IVA";
+$Edit_this_IVA = "Modifica questa percentuale di " . $IVA;
 $admin_footer_message = $CFG->myname . " \"<i>Commercio elettronico - Electronic Store</i>\"";
 $Brand_reset_for_products = "La marca &egrave; stata azzerata per i prodotti di tale marca";
-$IVA_reset_for_products = "La percentuale di IVA &egrave; stata azzerata per i prodotti con tale IVA";
+$IVA_reset_for_products = "La percentuale di " . $IVA . " &egrave; stata azzerata per i prodotti con tale " . $IVA;
 $Users = "Utenti";
 $Edit_this_order = "Modifica questo ordine";
 $Delete_this_order = "Cancella questo ordine";
@@ -423,7 +424,7 @@ $brand_name_too_long = "Il nome della marca &egrave; troppo lungo: ".$SESSION["b
 $brand_description_too_long = "La descrizione della marca &egrave; troppo lunga: ".$SESSION["brand_description_length"]." caratteri max";
 
 $Err_ImpBrand = ": La Marca non esiste - '";
-$Err_ImpIVA = ": L'IVA non esiste - '";
+$Err_ImpIVA = ": La " . $IVA . " non esiste - '";
 
 ////////////////////////////////////////////////////////////
 // add and update product
@@ -444,8 +445,8 @@ $price_is_zero = "Il Prezzo deve essere maggiore di zero";
 $price_notint = "Il campo del Prezzo deve contenere un numero intero, quindi solo cifre, nessun altro carattere";
 $price_notfloat = "Il campo del Prezzo deve contenere un numero decimale, quindi solo cifre e al pi&ugrave; un punto decimale, nessun altro carattere";
 
-$not_valid_iva = "Valore dell'IVA non valido";
-$iva_not_between_0_and_100 = "L'IVA non &egrave; compresa tra 0 e 100";
+$not_valid_iva = "Valore della " . $IVA . " non valido";
+$iva_not_between_0_and_100 = "La " . $IVA . " non &egrave; compresa tra 0 e 100";
 
 $discount_not_completely_defined = "Se si vuole fare sconti sul prodotto, bisogna riempire sia il campo \"" . $Discount . "\" che il campo \"" . $Starting_from . "\"; se non si vuole fare sconti sul prodotto, lasciare vuoti entrambi i campi";
 $not_valid_discount = "Sconto non valido";
