@@ -36,7 +36,8 @@ $The_category = "The category";
 $Brand = "Brand";
 $Brands = "Brands";
 $The_brand = "The brand";
-$The_IVA_Percentual = "The IVA percentual";
+global $IVA;	// taken from application.inc.php where the scope is a problem
+$The_IVA_Percentual = "The " . $IVA . " percentual";
 $Product = "Product";
 $Products = "Products";
 $The_product = "The product";
@@ -46,7 +47,7 @@ $Edit_Product = "Edit Product";
 $Items = "items";
 $Add_Subcategory = "Add Subcategory";
 $Add_Brand = "Add Brand";
-$Add_IVA = "Add IVA";
+$Add_IVA = "Add " . $IVA;
 $back = "back";
 $BACK = "BACK";
 $Address = "Address";
@@ -117,8 +118,8 @@ $Categories_Management = "Category Management";
 $C_Import_Categories = "Import categories";
 $Brands_Management = "Brands Management";
 $C_Import_Brands = "Import Brands";
-$C_Import_IVA = "Import IVA percentuals";
-$IVA_Management = "IVA Management";
+$C_Import_IVA = "Import ". $IVA . " percentuals";
+$IVA_Management = $IVA . " Management";
 $Orders_Log_ca = "Orders Log - Cash On Delivery";
 $Orders_Log_cc = "Orders Log - Credit Card";
 $Products_Management = "Products Management";
@@ -143,7 +144,7 @@ $Discount = "Discount";
 $Starting_from = "starting from";
 $C_Add_Category = "[+C] Add Category";
 $C_Add_Brand = "[+B] Add Brand";
-$C_Add_IVA = "[+I] Add IVA percentual";
+$C_Add_IVA = "[+I] Add " . $IVA . " percentual";
 $C_Add_Product = "[+P] Add Product";
 $Action = "Action";
 $User = "User";
@@ -163,10 +164,10 @@ $Add_a_subcategory_under = "Add a subcategory under";
 $Add_a_product_under = "Add a product under";
 $Edit_this_category = "Edit this category";
 $Edit_this_brand = "Edit this brand";
-$Edit_this_IVA = "Edit this IVA percentual";
+$Edit_this_IVA = "Edit this " . $IVA . " percentual";
 $admin_footer_message = $CFG->myname . " \"<i>Electronic Store - Commercio elettronico</i>\"";
 $Brand_reset_for_products = "The Brand has been reset for all products of that brand";
-$IVA_reset_for_products = "The IVA percentual has been reset for all products with that IVA percentual";
+$IVA_reset_for_products = "The " . $IVA . " percentual has been reset for all products with that " . $IVA . " percentual";
 $Users = "Users";
 $Edit_this_order = "Edit this order";
 $Delete_this_order = "Delete this order";
@@ -420,7 +421,7 @@ $brand_name_too_long = "Brand Name too much long: ".$SESSION["brand_name_length"
 $brand_description_too_long = "Brand Description too much long: ".$SESSION["brand_description_length"]." characters max";
 
 $Err_ImpBrand = ": the Brand doesn't exist - '";
-$Err_ImpIVA = ": the IVA doesn't exist - '";
+$Err_ImpIVA = ": the " . $IVA . " doesn't exist - '";
 
 ////////////////////////////////////////////////////////////
 // add and update product
@@ -441,8 +442,8 @@ $price_is_zero = "The Price must be greater than zero";
 $price_notint = "The Price entry must contain an integer number: only ciphers, not any other character";
 $price_notfloat = "The Price entry must contain a float number: only ciphers and optionally a dot, not any other character";
 
-$not_valid_iva = "IVA not valid";
-$iva_not_between_0_and_100 = "The IVA is not between 0 and 100";
+$not_valid_iva = $IVA . " not valid";
+$iva_not_between_0_and_100 = "The " . $IVA . " is not between 0 and 100";
 
 $discount_not_completely_defined = "If you want to discount the product, you have to fill both the fields \"" . $Discount . "\" and \"" . $Starting_from . "\"; if you do not want to discount the product, please leave empty both the fields";
 $not_valid_discount = "Discount not valid";
